@@ -159,7 +159,8 @@ class CortxJupyter(ContentsManager):
         with open('credentials.json',"w") as fp:
             json.dump(creds,fp)
 
-        print(json.load(open("credentials.json","r").read()))
+
+        print(json.load(open("credentials.json","r"))
         # with open('credentials.json',"r") as fp):
         #     print(json.load(fp))
 
